# Copyright (c) 2012 OpenStack, LLC
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
"""
Request Body limiting middleware.

"""

from oslo_log import log
from oslo_middleware import sizelimit

from manila.i18n import _LW

LOG = log.getLogger(__name__)


class RequestBodySizeLimiter(sizelimit.RequestBodySizeLimiter):
    def __init__(self, *args, **kwargs):
        LOG.warning(_LW('manila.api.sizelimit:RequestBodySizeLimiter and '
                        'manila.api.middleware.sizelimit:'
                        'RequestBodySizeLimiter '
                        'are deprecated. Please use '
                        'oslo_middleware.sizelimit: '
                        'RequestBodySizeLimiter instead.'))
        super(RequestBodySizeLimiter, self).__init__(*args, **kwargs)
